#include "bits/stdc++.h"
#include <ext/pb_ds/assoc_container.hpp>

using namespace std;
using namespace __gnu_pbds;
using ll = long long;

const ll MOD = 1'000'000'000 + 7;

// without "= X"
vector<vector<int>> get_mul_blocks(const vector<string> &expr) {
  vector<vector<int>> blks = {{}};
  for (const string &token : expr) {
    if (token == "+") {
      blks.emplace_back();
    } else if (token == "*") {
      continue;
    } else {
      blks.back().push_back(stoi(token));
    }
  }
  return blks;
}

int eval(const vector<vector<int>> &blks) {
  ll sum = 0;
  for (const vector<int> &bl : blks) {
    ll prod = 1;
    for (ll x : bl) {
      prod = (prod * x) % MOD;
    }
    sum += prod;
    if (sum >= MOD) sum -= MOD;
  }
  return (int)sum;
}

ll get_number_len(ll x) {
  int len = 1;
  ll bound = 10;
  while (x >= bound) {
    len++;
    bound *= 10;
  }
  return len;
}

ll set_digit(ll x, ll p10, ll new_val) {
  ll old = (x / p10) % 10;
  return x + (new_val - old) * p10;
}

ll fast_pow(ll a, ll n) {
  if (n == 0) return 1;
  if (n & 1) return (a * fast_pow(a, n - 1)) % MOD;
  ll res = fast_pow(a, n >> 1);
  return (res * res) % MOD;
}

ll div_mod(ll r, ll d) {
  return (r * fast_pow(d, MOD - 2)) % MOD;
}

ll add_mod(ll a, ll b) {
  return (a + b < MOD) ? (a + b) : (a + b - MOD);
}

ll sub_mod(ll a, ll b) {
  return (a < b) ? (MOD + a - b) : (a - b);
}

// elements are excluded
vector<int> prod_p, prod_s, bp, inverse_digits;
vector<vector<int>> block_prefixes, block_suffixes;
vector<vector<int>> num_len, blocks, inverses;

void init() {
  int n = blocks.size();

  num_len = blocks;
  prod_p.resize(n);
  prod_s.resize(n);
  bp.resize(n);
  block_prefixes.resize(n);
  block_suffixes.resize(n);
  inverse_digits.resize(10);
  inverses.resize(n);

  for (ll i = 1; i < 10; i++) {
    inverse_digits[i] = (int)div_mod(1, i);
  }

  for (int i = 0; i < n; i++) {
    inverses[i].resize(blocks[i].size());
    for (int j = 0; j < blocks[i].size(); j++) {
      inverses[i][j] = div_mod(1, blocks[i][j]);
    }
    for (auto &x : num_len[i]) {
      x = get_number_len(x);
    }
    block_prefixes[i].push_back(1);
    for (ll x : blocks[i]) {
      block_prefixes[i].push_back((int)(block_prefixes[i].back() * x % MOD));
    }
    bp[i] = block_prefixes[i].back();
    block_prefixes[i].pop_back();

    block_suffixes[i].push_back(1);
    for (int j = blocks[i].size() - 1; j > 0; j--) {
      block_suffixes[i].push_back((int)((ll)block_suffixes[i].back() * 
                                        blocks[i][j] % MOD));
    }
    reverse(block_suffixes[i].begin(), block_suffixes[i].end());
  }
  for (int i = 1; i < n; i++) {
    prod_p[i] = (int)add_mod(prod_p[i - 1], bp[i - 1]);
    prod_s[n - i - 1] = (int)add_mod(prod_s[n - i], bp[n - i]);
  }
}

int get_differ(ll x1, ll x2) {
  int diff = 0;
  if (x1 == 0 and x2 == 0) {
    return 0;
  }
  if ((x1 == 0 and x2 < 10) || (x2 == 0 and x1 < 10)) {
    return 1;
  }
  while (x1 > 0 and x2 > 0) {
    if (x1 % 10 != x2 % 10) {
      diff++;
    }
    x1 /= 10;
    x2 /= 10;
  }
  if (x1 != 0 or x2 != 0) { // not same length
    diff = 100;
  }
  return diff;
}

// can we change 1 or 2 digits in one number?
bool change_12(ll want) {
  for (int i = 0; i < blocks.size(); i++) {
    ll cnt = add_mod(prod_p[i], prod_s[i]);
    for (int j = 0; j < blocks[i].size(); j++) {
      ll in_block = ((ll)block_prefixes[i][j] * block_suffixes[i][j]) % MOD;
      ll expected_product = sub_mod(want, cnt);

      // if in_block is 0, than if expected is also zero, nothing should be changed.
      // otherwise product will be zero anyway and we will fail
      if (in_block != 0) {
        ll expect_num = div_mod(expected_product, in_block);
        if (get_differ(expect_num, blocks[i][j]) <= 2) {
          blocks[i][j] = (int)expect_num;
          return true;
        }
      }
    }
  }
  return false;
}

struct change_info {
  int delta;
  int i, j;
  int new_value;

  bool operator<(const change_info &other) const {
    return delta < other.delta;
  }
};

vector<change_info> get_block_change_data(int i) {
  vector<change_info> data;
  data.reserve(blocks[i].size() * 10 * 9); // no reallocations
  ll block_prod = bp[i];
  for (int j = 0; j < blocks[i].size(); j++) {
    ll p10 = 1;
    ll len = num_len[i][j];
    ll without = ((ll)block_prefixes[i][j] * block_suffixes[i][j]) % MOD;
    for (int d = 0; d < len; d++, p10 *= 10) {
      int start = 0;
      if (d + 1 == len && len > 1) start = 1;
      for (int new_digit = start; new_digit < 10; new_digit++) {
        ll new_val = set_digit(blocks[i][j], p10, new_digit);
        if (new_val >= MOD) {
          break;
        }
        ll new_prod = without * new_val % MOD;
        data.push_back({(int)sub_mod(new_prod, block_prod), i, j, (int)new_val});
      }
    }
  }
  return data;
}

bool change_2_different_blocks(ll want) {
  ll sum = eval(blocks);
  gp_hash_table<int, change_info> made_before;
  for (int i = 0; i < blocks.size(); i++) {
    auto cnt_block_changes = get_block_change_data(i);
    for (auto lst_change : cnt_block_changes) {
      ll delta1 = sub_mod(want, add_mod(lst_change.delta, sum));
      auto it = made_before.find((int)delta1);
      if (it != made_before.end()) {
        auto d1 = (*it).second;
        blocks[d1.i][d1.j] = d1.new_value;
        blocks[i][lst_change.j] = lst_change.new_value;
        return true;
      }
    }
    if (i + 1 != blocks.size()) {
      for (auto lst_change : cnt_block_changes) {
        made_before[lst_change.delta] = lst_change;
      }
    }
  }
  return false;
}

bool change_in_one_block(int i, ll want_block_product) {
  if (blocks[i].size() == 1) return false;
  int z1 = -1, z2 = -1;
  ll product_without_zeroes = 1, inv_product_without = 1;
  for (int j = 0; j < blocks[i].size(); j++) {
    if (blocks[i][j] == 0) {
      if (z1 == -1) {
        z1 = j;
      } else if (z2 == -1) {
        z2 = j;
      } else {
        return false;
      }
    } else {
      product_without_zeroes = (product_without_zeroes * blocks[i][j]) % MOD;
      inv_product_without = (inv_product_without * inverses[i][j]) % MOD;
    }
  }
  if (z1 == -1) {
    gp_hash_table<int, pair<int, int>> divs;
    ll ratio = want_block_product * inv_product_without % MOD;
    vector<pair<int, int>> update_pool;
    for (int j = 0; j < blocks[i].size(); j++) {

      ll p10 = 1;
      ll len = num_len[i][j];

      for (int d = 0; d < len; d++, p10 *= 10) {
        int start = 0;
        if (d + 1 == len && len > 1) start = 1;
        for (int new_digit = start; new_digit < 10; new_digit++) {
          ll new_val = set_digit(blocks[i][j], p10, new_digit);
          if (new_val >= MOD) {
            break;
          }
          ll d2 = sub_mod(new_val, blocks[i][j]);
          ll r2 = d2 * inverses[i][j] % MOD; // d2 / blocks[i][j]

          update_pool.emplace_back((int)r2, (int)new_val);

          if (r2 + 1 == MOD) {
            // In this case blocks[i][j] is a digit.
            // So this case is already covered by change_12
            continue;
          }
          ll r1 = sub_mod(ratio, 1 + r2) * div_mod(1, 1 + r2) % MOD;
          auto it = divs.find((int)r1);
          if (it != divs.end()) {
            auto prev_ch = (*it).second;
            blocks[i][prev_ch.first] = prev_ch.second;
            blocks[i][j] = new_val;
            return true;
          }
        }
      }
      for (auto p : update_pool) {
        divs[(int)p.first] = {j, p.second};
      }
      update_pool.clear();
    }
    return false;
  } else if (z2 == -1) {
    // one zero
    ll want_div_prod = want_block_product * inv_product_without % MOD;
    for (ll d = 1; d < 10; d++) { // replace zero with this
      for (int j = 0; j < blocks[i].size(); j++) {
        if (blocks[i][j] == 0) {
          continue;
        }
        //ll without_j = div_mod(product_without_zeroes, blocks[i][j]) * d % MOD;
        ll expect = (want_div_prod * blocks[i][j] % MOD) * (ll)inverse_digits[d] % MOD;
        if (get_differ(expect, blocks[i][j]) <= 1) {
          blocks[i][z1] = (int)d;
          blocks[i][j] = (int)expect;
          return true;
        }
      }
    }
    return false;
  } else {
    // two zeroes
    for (ll d1 = 1; d1 < 10; d1++) {
      for (ll d2 = d1; d2 < 10; d2++) {
        if ((product_without_zeroes * d1 * d2) % MOD == want_block_product) {
          blocks[i][z1] = (int)d1;
          blocks[i][z2] = (int)d2;
          return true;
        }
      }
    }
    return false;
  }
}

bool change_two_in_one_block(ll want) {
  for (int i = 0; i < blocks.size(); i++) {
    ll block_expect = sub_mod(want, add_mod(prod_p[i], prod_s[i]));
    if (change_in_one_block(i, block_expect)) {
      return true;
    }
  }
  return false;
}

void solve() {
  vector<string> input;
  string s;
  while (cin >> s) {
    input.push_back(s);
  }
  ll want = stoll(input.back());
  input.pop_back(); // want
  input.pop_back(); // =

  blocks = get_mul_blocks(input);
  auto old = blocks;

  init();

  if (eval(blocks) == want || change_12(want)
      || change_2_different_blocks(want)
      || change_two_in_one_block(want)) {
    cout << "YES\n";
    vector<pair<int, ll>> answer;
    int pos = 1;
    for (int i = 0; i < blocks.size(); i++) {
      for (int j = 0; j < blocks[i].size(); j++) {
        if (blocks[i][j] != old[i][j]) {
          answer.emplace_back(pos, blocks[i][j]);
        }
        pos++;
      }
    }
    cout << answer.size() << "\n";
    for (auto p : answer) {
      cout << p.first << " " << p.second << "\n";
    }
  } else {
    cout << "NO\n";
  }
}

int main() {
#ifdef LOCAL
  freopen("input.txt", "r", stdin);
  freopen("output.txt", "w", stdout);
#endif
  ios_base::sync_with_stdio(false);
  cin.tie(nullptr);
  cout.tie(nullptr);

  solve();
}
