//  Nikita Golikov, 2023

#include <bits/stdc++.h>

using namespace std;

using uint = unsigned int;
using ll = long long;
using ull = unsigned long long;

#ifdef GOLIKOV
    #define debug(x) cerr << (#x) << ":\t" << (x) << endl
#else
    #define debug(x) 238;
#endif

template <class A, class B>
bool smin(A& x, B&& y) {
  if (y < x) {
    x = y;
    return true;
  }
  return false;
}

template <class A, class B>
bool smax(A& x, B&& y) {
  if (x < y) {
    x = y;
    return true;
  }
  return false;
}

int main() {
#ifdef GOLIKOV
  assert(freopen("in", "rt", stdin));
  auto _clock_start = chrono::high_resolution_clock::now();
#endif
  ios::sync_with_stdio(false);
  cin.tie(nullptr);

  int n; cin >> n;
  vector<pair<int, int>> a(n);
  for (auto& [c, w] : a) {
    cin >> c >> w;
  }
  struct node {
    int cnt{};
    ll sumw{};
    pair<int, int> minC{int(1.1e9), -1};
    int sub{};

    node() = default;

    node operator+(node const& other) const {
      return node{cnt + other.cnt, sumw + other.sumw, min(minC, other.minC), 0};
    }

    void apply(int d) {
      sub += d;
      minC.first -= d;
    }
  };
  int pw = 1;
  while (pw < n) pw *= 2;
  vector<node> tree(2 * pw);
  for (int i = 0; i < n; ++i) {
    tree[pw + i].cnt = 1;
    tree[pw + i].sumw = a[i].second;
    tree[pw + i].minC = make_pair(a[i].first, i);
  }
  for (int i = pw - 1; i > 0; --i) {
    tree[i] = tree[2 * i] + tree[2 * i + 1];
  }

  auto push = [&](int v) {
    tree[2 * v].apply(tree[v].sub);
    tree[2 * v + 1].apply(tree[v].sub);
    tree[v].sub = 0;
  };

  auto Kill = [&](int pos) {
    auto rec = [&](auto&& self, int v, int l, int r) -> void {
      if (l + 1 == r) {
        tree[v].cnt = 0;
        tree[v].sumw = 0;
        tree[v].minC = make_pair(int(1.1e9), -1);
        return;
      }
      int m = (l + r) / 2;
      push(v);
      if (pos < m) {
        self(self, 2 * v, l, m);
      } else {
        self(self, 2 * v + 1, m, r);
      }
      tree[v] = tree[2 * v] + tree[2 * v + 1];
    };
    rec(rec, 1, 0, pw);
  };
  auto fix = [&] {
    while (true) {
      if (tree[1].minC.first > 0) {
        return;
      }
      int where = tree[1].minC.second;
      Kill(where);
    }
  };
  auto Get = [&](int ql, int qr) {
    auto rec = [&](auto&& self, int v, int l, int r) -> node {
      if (ql >= r || l >= qr) return node();
      if (ql <= l && r <= qr) return tree[v];
      int m = (l + r) / 2;
      push(v);
      return self(self, 2 * v, l, m) + self(self, 2 * v + 1, m, r);
    };
    return rec(rec, 1, 0, pw);
  };
  auto Add = [&](int ql, int qr) {
    auto rec = [&](auto&& self, int v, int l, int r) -> void {
      if (ql >= r || l >= qr) return;
      if (ql <= l && r <= qr) {
        tree[v].apply(1);
        return;
      }
      int m = (l + r) / 2;
      push(v);
      self(self, 2 * v, l, m);
      self(self, 2 * v + 1, m, r);
      tree[v] = tree[2 * v] + tree[2 * v + 1];
    };
    rec(rec, 1, 0, pw);
  };
  auto Descend = [&](int from, int here) {
    int ql = from;
    int qr = n;
    int ans = -1;
    auto rec = [&](auto&& self, int v, int l, int r) -> void {
      if (ql >= r || l >= qr) {
        return;
      }
      if (l + 1 == r) {
        here -= tree[v].cnt;
        ans = l + 1;
        return;
      }
      int m = (l + r) / 2;
      push(v);
      if (ql <= l && r <= qr) {
        if (tree[2 * v].cnt < here) {
          here -= tree[2 * v].cnt;
          if (tree[2 * v + 1].cnt < here) {
            here -= tree[2 * v + 1].cnt;
          } else {  
            self(self, 2 * v + 1, m, r); 
          }
        } else {
          self(self, 2 * v, l, m);
        }
      } else {
        self(self, 2 * v, l, m);
        if (here > 0) {
          self(self, 2 * v + 1, m, r);
        }
      }
    };
    rec(rec, 1, 0, pw);
    return ans;
  };

  int ptr = 0;
  for (int i = 0; i < n; ++i) {
    int here = a[i].first;
    ll res = 0;
    while (here) {
      fix();
      ll sum = tree[1].sumw;
      int cnt = tree[1].cnt;
      int minVal = tree[1].minC.first;
      assert(minVal > 0);
      if (cnt > here) {
        break;
      }
      int cycles = min(here / cnt, minVal);
      here -= cnt * cycles;
      res += sum * cycles;
      tree[1].apply(cycles);
    }
    fix();
    auto suffix = Get(ptr, n);
    if (suffix.cnt <= here) {
      Add(ptr, n);
      here -= suffix.cnt;
      res += suffix.sumw;
      ptr = 0;
    }
    if (here > 0) {
      fix();
      int right = Descend(ptr, here);
      // int left = ptr;
      // int right = n;
      // while (left + 1 != right) {
      //   int mid = (left + right) / 2;
      //   if (Get(ptr, mid).cnt >= here) {
      //     right = mid;
      //   } else {
      //     left = mid;
      //   }
      // }
      res += Get(ptr, right).sumw;
      Add(ptr, right);
      ptr = right % n;
    }
    cout << res << ' ';
  }
  cout << '\n';

#ifdef GOLIKOV
  cerr << "Executed in " << chrono::duration_cast<chrono::milliseconds>(
      chrono::high_resolution_clock::now()
          - _clock_start).count() << "ms." << endl;
#endif
  return 0;
}
